@@ -2,6 +2,10 @@ from . import fmt
 from . import utils
 
 
+def get_tag(config, name):
+    return config["DOCKER_IMAGE_" + name.upper().replace("-", "_")]
+
+
 def build(path, tag, no_cache=False, build_args=None):
     fmt.echo_info("Building image {}".format(tag))
     command = ["build", "-t", tag, path]
